==> webpack-node-module-types-1.0.2.tgz: package/CHANGELOG.md <==
[v1.0.2]: https://github.com/Xunnamius/webpack-node-module-types/compare/v1.0.1...v1.0.2
[v1.0.1]: https://github.com/Xunnamius/webpack-node-module-types/compare/v1.0.0...v1.0.1
[v1.0.0]: https://github.com/Xunnamius/webpack-node-module-types/releases/tag/v1.0.0

[https://keepachangelog.com/en/1.0.0/]::

[types of changes]::
  [added]:: (for new features)
  [changed]:: (for changes in existing functionality)
  [deprecated]:: (for soon-to-be removed features)
  [removed]:: (for now removed features)
  [fixed]:: (for any bug fixes)
  [security]:: (in case of vulnerabilities)

# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Upcoming]

(no notes yet)

## Released

### [![v1.0.2](https://api.ergodark.com/badges/github-tag-date/xunnamius/webpack-node-module-types/v1.0.2)][v1.0.2]
#### Added
- Backwards compat with Node versions all the way back to v10 LTS

---

### [![v1.0.1](https://api.ergodark.com/badges/github-tag-date/xunnamius/webpack-node-module-types/v1.0.1)][v1.0.1]
#### Added
- Synchronous and asynchronous entry points via (`/sync` and `/async`). The
  default bare export still returns the asynchronous API.

#### Changed
- Updated README
- Added more tests

---

### [![v1.0.0](https://api.ergodark.com/badges/github-tag-date/xunnamius/webpack-node-module-types/v1.0.0)][v1.0.0]
#### Added
- Initial release

[Upcoming]: https://github.com/Xunnamius/webpack-node-module-types/compare/main...develop

==> webpack-node-module-types-1.0.3.tgz: package/CHANGELOG.md <==
[v1.0.3]: https://github.com/Xunnamius/webpack-node-module-types/compare/v1.0.2...v1.0.3
[v1.0.2]: https://github.com/Xunnamius/webpack-node-module-types/compare/v1.0.1...v1.0.2
[v1.0.1]: https://github.com/Xunnamius/webpack-node-module-types/compare/v1.0.0...v1.0.1
[v1.0.0]: https://github.com/Xunnamius/webpack-node-module-types/releases/tag/v1.0.0

[https://keepachangelog.com/en/1.0.0/]::

[types of changes]::
  [added]:: (for new features)
  [changed]:: (for changes in existing functionality)
  [deprecated]:: (for soon-to-be removed features)
  [removed]:: (for now removed features)
  [fixed]:: (for any bug fixes)
  [security]:: (in case of vulnerabilities)

# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Upcoming]

(no notes yet)

## Released

### [![v1.0.3](https://api.ergodark.com/badges/github-tag-date/xunnamius/webpack-node-module-types/v1.0.3)][v1.0.3]
#### Fixed
- Added TypeScript types to `/sync` and `/async`
- Fixed bug where `/sync` and `/async` entry points were not allowed in `package.json`

---

### [![v1.0.2](https://api.ergodark.com/badges/github-tag-date/xunnamius/webpack-node-module-types/v1.0.2)][v1.0.2]
#### Added
- Backwards compat with Node versions all the way back to v10 LTS

---

### [![v1.0.1](https://api.ergodark.com/badges/github-tag-date/xunnamius/webpack-node-module-types/v1.0.1)][v1.0.1]
#### Added
- Synchronous and asynchronous entry points via (`/sync` and `/async`). The
  default bare export still returns the asynchronous API

#### Changed
- Updated README
- Added more tests

---

### [![v1.0.0](https://api.ergodark.com/badges/github-tag-date/xunnamius/webpack-node-module-types/v1.0.0)][v1.0.0]
#### Added
- Initial release

[Upcoming]: https://github.com/Xunnamius/webpack-node-module-types/compare/main...develop
